@@ -110,7 +110,7 @@ def _annotate_median(self: TypeAnnotator, expression: exp.Median) -> exp.Median:
     """Annotate MEDIAN function with correct return type.
 
     Based on Snowflake documentation:
-    - If the expr is FLOAT -> annotate as FLOAT
+    - If the expr is FLOAT/DOUBLE -> annotate as DOUBLE (FLOAT is a synonym for DOUBLE)
     - If the expr is NUMBER(p, s) -> annotate as NUMBER(min(p+3, 38), min(s+3, 37))
     """
     # First annotate the argument to get its type
@@ -119,9 +119,9 @@ def _annotate_median(self: TypeAnnotator, expression: exp.Median) -> exp.Median:
     # Get the input type
     input_type = expression.this.type
 
-    if input_type.is_type(exp.DataType.Type.FLOAT):
-        # If input is FLOAT, return FLOAT
-        self._set_type(expression, exp.DataType.Type.FLOAT)
+    if input_type.is_type(exp.DataType.Type.DOUBLE):
+        # If input is FLOAT/DOUBLE, return DOUBLE (FLOAT is normalized to DOUBLE in Snowflake)
+        self._set_type(expression, exp.DataType.Type.DOUBLE)
     else:
         # If input is NUMBER(p, s), return NUMBER(min(p+3, 38), min(s+3, 37))
         exprs = input_type.expressions
@@ -180,6 +180,29 @@ def _annotate_variance(self: TypeAnnotator, expression: exp.Expression) -> exp.E
     return expression
 
 
+def _annotate_kurtosis(self: TypeAnnotator, expression: exp.Kurtosis) -> exp.Kurtosis:
+    """Annotate KURTOSIS with correct return type.
+
+    Based on Snowflake behavior:
+    - DECFLOAT input -> DECFLOAT
+    - DOUBLE or FLOAT input -> DOUBLE
+    - Other numeric types (INT, NUMBER) -> NUMBER(38, 12)
+    """
+    expression = self._annotate_by_args(expression, "this")
+    input_type = expression.this.type
+
+    if input_type.is_type(exp.DataType.Type.DECFLOAT):
+        self._set_type(expression, exp.DataType.build("DECFLOAT", dialect="snowflake"))
+    elif input_type.is_type(exp.DataType.Type.FLOAT, exp.DataType.Type.DOUBLE):
+        self._set_type(expression, exp.DataType.Type.DOUBLE)
+    else:
+        self._set_type(
+            expression, exp.DataType.build(f"NUMBER({MAX_PRECISION}, 12)", dialect="snowflake")
+        )
+
+    return expression
+
+
 def _annotate_math_with_float_decfloat(
     self: TypeAnnotator, expression: exp.Expression
 ) -> exp.Expression:
@@ -202,6 +225,18 @@ def _annotate_math_with_float_decfloat(
     return expression
 
 
+def _annotate_str_to_time(self: TypeAnnotator, expression: exp.StrToTime) -> exp.StrToTime:
+    # target_type is stored as a DataType instance
+    target_type_arg = expression.args.get("target_type")
+    target_type = (
+        target_type_arg.this
+        if isinstance(target_type_arg, exp.DataType)
+        else exp.DataType.Type.TIMESTAMP
+    )
+    self._set_type(expression, target_type)
+    return expression
+
+
 EXPRESSION_METADATA = {
     **EXPRESSION_METADATA,
     **{
@@ -227,10 +262,18 @@ EXPRESSION_METADATA = {
         for expr_type in (
             exp.ApproxTopK,
             exp.ApproxTopKEstimate,
+            exp.Array,
             exp.ArrayAgg,
+            exp.ArrayAppend,
+            exp.ArrayCompact,
+            exp.ArrayConcat,
             exp.ArrayConstructCompact,
+            exp.ArrayPrepend,
+            exp.ArrayRemove,
+            exp.ArraysZip,
             exp.ArrayUniqueAgg,
             exp.ArrayUnionAgg,
+            exp.MapKeys,
             exp.RegexpExtractAll,
             exp.Split,
             exp.StringToArray,
@@ -247,6 +290,7 @@ EXPRESSION_METADATA = {
             exp.MD5NumberLower64,
             exp.MD5NumberUpper64,
             exp.Rand,
+            exp.Seq8,
             exp.Zipf,
         }
     },
@@ -258,6 +302,10 @@ EXPRESSION_METADATA = {
             exp.BitmapOrAgg,
             exp.Compress,
             exp.DecompressBinary,
+            exp.Decrypt,
+            exp.DecryptRaw,
+            exp.Encrypt,
+            exp.EncryptRaw,
             exp.HexString,
             exp.MD5Digest,
             exp.SHA1Digest,
@@ -277,6 +325,7 @@ EXPRESSION_METADATA = {
             exp.BoolxorAgg,
             exp.EqualNull,
             exp.IsNullValue,
+            exp.MapContainsKey,
             exp.Search,
             exp.SearchIp,
             exp.ToBoolean,
@@ -301,6 +350,7 @@ EXPRESSION_METADATA = {
             exp.BitwiseXorAgg,
             exp.RegexpCount,
             exp.RegexpInstr,
+            exp.ToNumber,
         )
     },
     **{
@@ -310,9 +360,10 @@ EXPRESSION_METADATA = {
             exp.ApproximateSimilarity,
             exp.Asinh,
             exp.Atanh,
-            exp.Cbrt,
             exp.Cosh,
             exp.CosineDistance,
+            exp.CovarPop,
+            exp.CovarSamp,
             exp.DotProduct,
             exp.EuclideanDistance,
             exp.ManhattanDistance,
@@ -321,6 +372,7 @@ EXPRESSION_METADATA = {
             exp.Sinh,
         }
     },
+    exp.Kurtosis: {"annotator": _annotate_kurtosis},
     **{
         expr_type: {"returns": exp.DataType.Type.DECFLOAT}
         for expr_type in {
@@ -335,6 +387,7 @@ EXPRESSION_METADATA = {
             exp.Asin,
             exp.Atan,
             exp.Atan2,
+            exp.Cbrt,
             exp.Cos,
             exp.Cot,
             exp.Degrees,
@@ -363,40 +416,66 @@ EXPRESSION_METADATA = {
     **{
         expr_type: {"returns": exp.DataType.Type.INT}
         for expr_type in {
-            exp.Ascii,
-            exp.BitLength,
             exp.ByteLength,
-            exp.Getbit,
             exp.Grouping,
             exp.Hour,
             exp.JarowinklerSimilarity,
-            exp.Length,
-            exp.Levenshtein,
+            exp.MapSize,
             exp.Minute,
             exp.RtrimmedLength,
             exp.Second,
-            exp.StrPosition,
-            exp.Unicode,
+            exp.Seq1,
+            exp.Seq2,
+            exp.Seq4,
             exp.WidthBucket,
         }
     },
     **{
         expr_type: {"returns": exp.DataType.Type.OBJECT}
         for expr_type in {
+            exp.ApproxPercentileAccumulate,
+            exp.ApproxPercentileCombine,
+            exp.ApproxTopKAccumulate,
+            exp.ApproxTopKCombine,
             exp.ObjectAgg,
             exp.ParseIp,
             exp.ParseUrl,
-            exp.ApproxPercentileCombine,
-            exp.ApproxPercentileAccumulate,
-            exp.ApproxTopKAccumulate,
-            exp.ApproxTopKCombine,
             exp.XMLGet,
         }
     },
+    **{
+        expr_type: {"returns": exp.DataType.Type.MAP}
+        for expr_type in {
+            exp.MapCat,
+            exp.MapDelete,
+            exp.MapInsert,
+            exp.MapPick,
+        }
+    },
+    **{
+        expr_type: {"returns": exp.DataType.Type.FILE}
+        for expr_type in {
+            exp.ToFile,
+        }
+    },
     **{
         expr_type: {"returns": exp.DataType.Type.TIME}
         for expr_type in {
             exp.TimeFromParts,
+            exp.TsOrDsToTime,
+        }
+    },
+    **{
+        expr_type: {"returns": exp.DataType.Type.TIMESTAMPLTZ}
+        for expr_type in {
+            exp.CurrentTimestamp,
+            exp.Localtimestamp,
+        }
+    },
+    **{
+        expr_type: {"returns": exp.DataType.Type.TINYINT}
+        for expr_type in {
+            exp.Quarter,
         }
     },
     **{
@@ -409,7 +488,6 @@ EXPRESSION_METADATA = {
             exp.Base64Encode,
             exp.CheckJson,
             exp.CheckXml,
-            exp.Chr,
             exp.Collate,
             exp.Collation,
             exp.CurrentAccount,
@@ -433,7 +511,6 @@ EXPRESSION_METADATA = {
             exp.DecompressString,
             exp.HexDecodeString,
             exp.HexEncode,
-            exp.Initcap,
             exp.MD5,
             exp.Monthname,
             exp.Randstr,
@@ -441,11 +518,8 @@ EXPRESSION_METADATA = {
             exp.RegexpReplace,
             exp.Repeat,
             exp.Replace,
-            exp.SHA,
-            exp.SHA2,
             exp.Soundex,
             exp.SoundexP123,
-            exp.Space,
             exp.SplitPart,
             exp.Translate,
             exp.TryBase64DecodeString,
@@ -480,17 +554,14 @@ EXPRESSION_METADATA = {
     },
     exp.DateAdd: {"annotator": _annotate_date_or_time_add},
     exp.DecodeCase: {"annotator": _annotate_decode_case},
-    exp.GreatestIgnoreNulls: {
-        "annotator": lambda self, e: self._annotate_by_args(e, "expressions")
-    },
     exp.HashAgg: {
         "annotator": lambda self, e: self._set_type(
             e, exp.DataType.build("NUMBER(19, 0)", dialect="snowflake")
         )
     },
-    exp.LeastIgnoreNulls: {"annotator": lambda self, e: self._annotate_by_args(e, "expressions")},
     exp.Median: {"annotator": _annotate_median},
     exp.Reverse: {"annotator": _annotate_reverse},
+    exp.StrToTime: {"annotator": _annotate_str_to_time},
     exp.TimeAdd: {"annotator": _annotate_date_or_time_add},
     exp.TimestampFromParts: {"annotator": _annotate_timestamp_from_parts},
     exp.WithinGroup: {"annotator": _annotate_within_group},
