@@ -152,6 +152,12 @@ DOUBLE;
 CBRT(tbl.double_col);
 DOUBLE;
 
+ISINF(tbl.float_col);
+BOOLEAN;
+
+ISNAN(tbl.float_col);
+BOOLEAN;
+
 # dialect: snowflake
 TO_BINARY('test');
 BINARY;
@@ -5556,10 +5562,22 @@ NVARCHAR;
 SOUNDEX(tbl.str_col);
 VARCHAR;
 
+# dialect: tsql
+STUFF(tbl.str_col, tbl.int_col, tbl.int_col, tbl.str_col);
+VARCHAR;
+
 --------------------------------------
 -- MySQL
 --------------------------------------
 
+# dialect: mysql
+DEGREES(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql
+DEGREES(tbl.int_col);
+DOUBLE;
+
 # dialect: mysql
 LOCALTIME;
 DATETIME;
@@ -5572,6 +5590,106 @@ VARCHAR;
 DAYOFWEEK(tbl.date_col);
 INT;
 
+# dialect: mysql
+MONTH(tbl.date_col);
+INT;
+
+# dialect: mysql
+QUARTER(tbl.date_col);
+INT;
+
+# dialect: mysql
+SECOND(tbl.time_col);
+INT;
+
+# dialect: mysql
+SIN(tbl.int_col);
+DOUBLE;
+
+# dialect: mysql
+SIN(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+COS(tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+COS(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+TAN(tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+TAN(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+COT(tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+COT(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+ASIN(tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+ASIN(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+ACOS(tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+ACOS(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN(tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN(tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN(tbl.int_col, tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN(tbl.double_col, tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN2(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN2(tbl.int_col, tbl.double_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN2(tbl.double_col, tbl.int_col);
+DOUBLE;
+
+# dialect: mysql 
+ATAN2(tbl.double_col, tbl.double_col);
+DOUBLE;
+
 --------------------------------------
 -- DuckDB
 --------------------------------------
@@ -5590,4 +5708,124 @@ INT;
 
 # dialect: duckdb
 FACTORIAL(tbl.int_col);
-HUGEINT
\ No newline at end of file
+HUGEINT;
+
+# dialect: duckdb
+SIN(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+SIN(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ASIN(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+ASIN(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+COS(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+COS(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ACOS(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+ACOS(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+COT(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+COT(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+TAN(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+TAN(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ATAN(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+ATAN(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ATAN2(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+ATAN2(tbl.int_col, tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ATAN2(tbl.double_col, tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+ATAN2(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ACOSH(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+ACOSH(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ASINH(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+ASINH(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ATANH(tbl.int_col);
+DOUBLE;
+
+# dialect: duckdb
+ATANH(tbl.double_col);
+DOUBLE;
+
+# dialect: duckdb
+ISINF(tbl.float_col);
+BOOLEAN;
+
+# dialect: duckdb
+RANDOM();
+DOUBLE;
+
+# dialect: duckdb
+QUARTER(tbl.date_col);
+BIGINT;
+
+# dialect: duckdb
+QUARTER(tbl.timestamp_col);
+BIGINT;
+
+# dialect: duckdb
+QUARTER(tbl.interval_col);
+BIGINT;
+
+# dialect: duckdb
+QUARTER(tbl.timestamp_tz_col);
+BIGINT;
\ No newline at end of file
